==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TileSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ShapeSeriesBaseDescription } from "./ShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TileSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TileSeriesDescription, _super);
    function TileSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.dv = null;
        return _this;
    }
    TileSeriesDescription.prototype.get_type = function () {
        return "TileSeries";
    };
    Object.defineProperty(TileSeriesDescription.prototype, "tileImagery", {
        get: function () {
            return this.dv;
        },
        set: function (a) {
            this.dv = a;
            this.e("TileImagery");
        },
        enumerable: false,
        configurable: true
    });
    TileSeriesDescription.$t = markType(TileSeriesDescription, 'TileSeriesDescription', ShapeSeriesBaseDescription.$);
    return TileSeriesDescription;
}(ShapeSeriesBaseDescription));
export { TileSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/TileSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ShapeSeriesBaseDescription } from "./ShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TileSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TileSeriesDescription, _super);
    function TileSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.f3 = null;
        return _this;
    }
    TileSeriesDescription.prototype.get_type = function () {
        return "TileSeries";
    };
    Object.defineProperty(TileSeriesDescription.prototype, "tileImagery", {
        get: function () {
            return this.f3;
        },
        set: function (a) {
            this.f3 = a;
            this.g("TileImagery");
        },
        enumerable: false,
        configurable: true
    });
    TileSeriesDescription.$t = markType(TileSeriesDescription, 'TileSeriesDescription', ShapeSeriesBaseDescription.$);
    return TileSeriesDescription;
}(ShapeSeriesBaseDescription));
export { TileSeriesDescription };
